==> qtbase-everywhere-src-5.14.1.tar.xz: qtbase-everywhere-src-5.14.1/src/gui/vulkan/qplatformvulkaninstance.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qplatformvulkaninstance.h"

QT_BEGIN_NAMESPACE

/*!
    \class QPlatformVulkanInstance
    \since 5.10
    \internal
    \preliminary
    \ingroup qpa

    \brief The QPlatformVulkanInstance class provides an abstraction for Vulkan instances.

    The platform Vulkan instance is responsible for loading a Vulkan library,
    resolving the basic entry points for creating instances, providing support
    for creating new or adopting existing VkInstances, and abstracting some
    WSI-specifics like checking if a given queue family can be used to present
    using a given window.

    \note platform plugins will typically subclass not this class, but rather
    QBasicVulkanPlatformInstance.

    \note Vulkan instance creation is split into two phases: a new
    QPlatformVulkanInstance is expected to load the Vulkan library and do basic
    initialization, after which the supported layers and extensions can be
    queried. Everything else is deferred into createOrAdoptInstance().
*/

class QPlatformVulkanInstancePrivate
{
public:
    QPlatformVulkanInstancePrivate() { }
};

QPlatformVulkanInstance::QPlatformVulkanInstance()
    : d_ptr(new QPlatformVulkanInstancePrivate)
{
}

QPlatformVulkanInstance::~QPlatformVulkanInstance()
{
}

void QPlatformVulkanInstance::presentQueued(QWindow *window)
{
    Q_UNUSED(window);
}

void QPlatformVulkanInstance::setDebugFilters(const QVector<QVulkanInstance::DebugFilter> &filters)
{
    Q_UNUSED(filters);
}

QT_END_NAMESPACE

==> qtbase-everywhere-src-6.0.1.tar.xz: qtbase-everywhere-src-6.0.1/src/gui/vulkan/qplatformvulkaninstance.cpp <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qplatformvulkaninstance.h"

QT_BEGIN_NAMESPACE

/*!
    \class QPlatformVulkanInstance
    \since 5.10
    \internal
    \preliminary
    \ingroup qpa

    \brief The QPlatformVulkanInstance class provides an abstraction for Vulkan instances.

    The platform Vulkan instance is responsible for loading a Vulkan library,
    resolving the basic entry points for creating instances, providing support
    for creating new or adopting existing VkInstances, and abstracting some
    WSI-specifics like checking if a given queue family can be used to present
    using a given window.

    \note platform plugins will typically subclass not this class, but rather
    QBasicVulkanPlatformInstance.

    \note Vulkan instance creation is split into two phases: a new
    QPlatformVulkanInstance is expected to load the Vulkan library and do basic
    initialization, after which the supported layers and extensions can be
    queried. Everything else is deferred into createOrAdoptInstance().
*/

class QPlatformVulkanInstancePrivate
{
public:
    QPlatformVulkanInstancePrivate() { }
};

QPlatformVulkanInstance::QPlatformVulkanInstance()
    : d_ptr(new QPlatformVulkanInstancePrivate)
{
}

QPlatformVulkanInstance::~QPlatformVulkanInstance()
{
}

void QPlatformVulkanInstance::presentAboutToBeQueued(QWindow *window)
{
    Q_UNUSED(window);
}

void QPlatformVulkanInstance::presentQueued(QWindow *window)
{
    Q_UNUSED(window);
}

void QPlatformVulkanInstance::setDebugFilters(const QList<QVulkanInstance::DebugFilter> &filters)
{
    Q_UNUSED(filters);
}

QT_END_NAMESPACE
